Index: src/ports/SkFontMgr_empty_factory.cpp |
diff --git a/src/ports/SkFontMgr_empty_factory.cpp b/src/ports/SkFontMgr_empty_factory.cpp |
index ceed8f33205853728bdefe974da353253e0fb706..b4232cde1270870bd6cb40e82b710e52377dfa1f 100644 |
--- a/src/ports/SkFontMgr_empty_factory.cpp |
+++ b/src/ports/SkFontMgr_empty_factory.cpp |
@@ -8,6 +8,6 @@ |
#include "SkFontMgr.h" |
SkFontMgr* SkFontMgr::Factory() { |
- // Always return NULL, an empty SkFontMgr will be used. |
- return NULL; |
+ // Always return nullptr, an empty SkFontMgr will be used. |
+ return nullptr; |
} |